# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from Tea.model import TeaModel
from typing import Dict


class AISearchQuery(TeaModel):
    def __init__(
        self,
        card: str = None,
        query: str = None,
    ):
        self.card = card
        self.query = query

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.card is not None:
            result['card'] = self.card
        if self.query is not None:
            result['query'] = self.query
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('card') is not None:
            self.card = m.get('card')
        if m.get('query') is not None:
            self.query = m.get('query')
        return self


class EventHeader(TeaModel):
    def __init__(
        self,
        event: str = None,
        event_id: str = None,
        request_id: str = None,
        response_time: int = None,
    ):
        self.event = event
        self.event_id = event_id
        self.request_id = request_id
        self.response_time = response_time

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.event is not None:
            result['event'] = self.event
        if self.event_id is not None:
            result['eventId'] = self.event_id
        if self.request_id is not None:
            result['requestId'] = self.request_id
        if self.response_time is not None:
            result['responseTime'] = self.response_time
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('event') is not None:
            self.event = m.get('event')
        if m.get('eventId') is not None:
            self.event_id = m.get('eventId')
        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')
        if m.get('responseTime') is not None:
            self.response_time = m.get('responseTime')
        return self


class AISearchResult(TeaModel):
    def __init__(
        self,
        header: EventHeader = None,
        payload: str = None,
        request_id: str = None,
    ):
        self.header = header
        self.payload = payload
        self.request_id = request_id

    def validate(self):
        if self.header:
            self.header.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.header is not None:
            result['header'] = self.header.to_map()
        if self.payload is not None:
            result['payload'] = self.payload
        if self.request_id is not None:
            result['requestId'] = self.request_id
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('header') is not None:
            temp_model = EventHeader()
            self.header = temp_model.from_map(m['header'])
        if m.get('payload') is not None:
            self.payload = m.get('payload')
        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')
        return self


class AISearchRequest(TeaModel):
    def __init__(
        self,
        card: str = None,
        query: str = None,
    ):
        self.card = card
        # This parameter is required.
        self.query = query

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.card is not None:
            result['card'] = self.card
        if self.query is not None:
            result['query'] = self.query
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('card') is not None:
            self.card = m.get('card')
        if m.get('query') is not None:
            self.query = m.get('query')
        return self


class AISearchResponseBodyHeader(TeaModel):
    def __init__(
        self,
        event: str = None,
        event_id: str = None,
        request_id: str = None,
        response_time: str = None,
    ):
        self.event = event
        self.event_id = event_id
        self.request_id = request_id
        self.response_time = response_time

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.event is not None:
            result['event'] = self.event
        if self.event_id is not None:
            result['eventId'] = self.event_id
        if self.request_id is not None:
            result['requestId'] = self.request_id
        if self.response_time is not None:
            result['responseTime'] = self.response_time
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('event') is not None:
            self.event = m.get('event')
        if m.get('eventId') is not None:
            self.event_id = m.get('eventId')
        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')
        if m.get('responseTime') is not None:
            self.response_time = m.get('responseTime')
        return self


class AISearchResponseBody(TeaModel):
    def __init__(
        self,
        header: AISearchResponseBodyHeader = None,
        payload: str = None,
        request_id: str = None,
    ):
        self.header = header
        self.payload = payload
        self.request_id = request_id

    def validate(self):
        if self.header:
            self.header.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.header is not None:
            result['header'] = self.header.to_map()
        if self.payload is not None:
            result['payload'] = self.payload
        if self.request_id is not None:
            result['requestId'] = self.request_id
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('header') is not None:
            temp_model = AISearchResponseBodyHeader()
            self.header = temp_model.from_map(m['header'])
        if m.get('payload') is not None:
            self.payload = m.get('payload')
        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')
        return self


class AISearchResponse(TeaModel):
    def __init__(
        self,
        headers: Dict[str, str] = None,
        status_code: int = None,
        body: AISearchResponseBody = None,
    ):
        self.headers = headers
        self.status_code = status_code
        self.body = body

    def validate(self):
        if self.body:
            self.body.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.headers is not None:
            result['headers'] = self.headers
        if self.status_code is not None:
            result['statusCode'] = self.status_code
        if self.body is not None:
            result['body'] = self.body.to_map()
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('headers') is not None:
            self.headers = m.get('headers')
        if m.get('statusCode') is not None:
            self.status_code = m.get('statusCode')
        if m.get('body') is not None:
            temp_model = AISearchResponseBody()
            self.body = temp_model.from_map(m['body'])
        return self





# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from typing import Dict
from Tea.core import TeaCore

from alibabacloud_tea_openapi.client import Client as OpenApiClient
from alibabacloud_tea_openapi import models as open_api_models
from alibabacloud_tea_util.client import Client as UtilClient
from alibabacloud_endpoint_util.client import Client as EndpointUtilClient
from alibabacloud_linkedmallretrieval20240501 import models as linkedmall_retrieval_20240501_models
from alibabacloud_tea_util import models as util_models
from alibabacloud_openapi_util.client import Client as OpenApiUtilClient


class Client(OpenApiClient):
    """
    *\
    """
    def __init__(
        self, 
        config: open_api_models.Config,
    ):
        super().__init__(config)
        self._endpoint_rule = ''
        self.check_config(config)
        self._endpoint = self.get_endpoint('linkedmallretrieval', self._region_id, self._endpoint_rule, self._network, self._suffix, self._endpoint_map, self._endpoint)

    def get_endpoint(
        self,
        product_id: str,
        region_id: str,
        endpoint_rule: str,
        network: str,
        suffix: str,
        endpoint_map: Dict[str, str],
        endpoint: str,
    ) -> str:
        if not UtilClient.empty(endpoint):
            return endpoint
        if not UtilClient.is_unset(endpoint_map) and not UtilClient.empty(endpoint_map.get(region_id)):
            return endpoint_map.get(region_id)
        return EndpointUtilClient.get_endpoint_rules(product_id, region_id, endpoint_rule, network, suffix)

    def a_isearch_with_options(
        self,
        request: linkedmall_retrieval_20240501_models.AISearchRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> linkedmall_retrieval_20240501_models.AISearchResponse:
        """
        @summary AI搜索
        
        @param request: AISearchRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: AISearchResponse
        """
        UtilClient.validate_model(request)
        query = {}
        if not UtilClient.is_unset(request.card):
            query['card'] = request.card
        if not UtilClient.is_unset(request.query):
            query['query'] = request.query
        req = open_api_models.OpenApiRequest(
            headers=headers,
            query=OpenApiUtilClient.query(query)
        )
        params = open_api_models.Params(
            action='AISearch',
            version='2024-05-01',
            protocol='HTTPS',
            pathname=f'/linked-retrieval/linked-retrieval-entry/v1/linkedRetrieval/commands/aiSearch',
            method='GET',
            auth_type='AK',
            style='ROA',
            req_body_type='json',
            body_type='json'
        )
        return TeaCore.from_map(
            linkedmall_retrieval_20240501_models.AISearchResponse(),
            self.call_api(params, req, runtime)
        )

    async def a_isearch_with_options_async(
        self,
        request: linkedmall_retrieval_20240501_models.AISearchRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> linkedmall_retrieval_20240501_models.AISearchResponse:
        """
        @summary AI搜索
        
        @param request: AISearchRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: AISearchResponse
        """
        UtilClient.validate_model(request)
        query = {}
        if not UtilClient.is_unset(request.card):
            query['card'] = request.card
        if not UtilClient.is_unset(request.query):
            query['query'] = request.query
        req = open_api_models.OpenApiRequest(
            headers=headers,
            query=OpenApiUtilClient.query(query)
        )
        params = open_api_models.Params(
            action='AISearch',
            version='2024-05-01',
            protocol='HTTPS',
            pathname=f'/linked-retrieval/linked-retrieval-entry/v1/linkedRetrieval/commands/aiSearch',
            method='GET',
            auth_type='AK',
            style='ROA',
            req_body_type='json',
            body_type='json'
        )
        return TeaCore.from_map(
            linkedmall_retrieval_20240501_models.AISearchResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def a_isearch(
        self,
        request: linkedmall_retrieval_20240501_models.AISearchRequest,
    ) -> linkedmall_retrieval_20240501_models.AISearchResponse:
        """
        @summary AI搜索
        
        @param request: AISearchRequest
        @return: AISearchResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return self.a_isearch_with_options(request, headers, runtime)

    async def a_isearch_async(
        self,
        request: linkedmall_retrieval_20240501_models.AISearchRequest,
    ) -> linkedmall_retrieval_20240501_models.AISearchResponse:
        """
        @summary AI搜索
        
        @param request: AISearchRequest
        @return: AISearchResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return await self.a_isearch_with_options_async(request, headers, runtime)
